(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/platform-browser'), require('@angular/common'), require('@angular/core')) :
    typeof define === 'function' && define.amd ? define('ngx-metafrenzy', ['exports', '@angular/platform-browser', '@angular/common', '@angular/core'], factory) :
    (factory((global['ngx-metafrenzy'] = {}),global.ng.platformBrowser,global.ng.common,global.ng.core));
}(this, (function (exports,platformBrowser,common,core) { 'use strict';

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var MetafrenzyService = /** @class */ (function () {
        function MetafrenzyService(title, meta, rendererFactory, document) {
            this.title = title;
            this.meta = meta;
            this.rendererFactory = rendererFactory;
            this.document = document;
        }
        /**
         * @param {?} title
         * @return {?}
         */
        MetafrenzyService.prototype.setTitle = /**
         * @param {?} title
         * @return {?}
         */
            function (title) {
                this.title.setTitle(title);
            };
        /**
         * @return {?}
         */
        MetafrenzyService.prototype.getTitle = /**
         * @return {?}
         */
            function () {
                return this.title.getTitle();
            };
        /**
         * @param {?} name
         * @param {?} content
         * @return {?}
         */
        MetafrenzyService.prototype.setMetaTag = /**
         * @param {?} name
         * @param {?} content
         * @return {?}
         */
            function (name, content) {
                /** @type {?} */
                var metaDefinition = {};
                if (name.lastIndexOf('og:', 0) === 0) {
                    metaDefinition['property'] = name;
                }
                else {
                    metaDefinition['name'] = name;
                }
                metaDefinition['content'] = content;
                this.meta.updateTag(metaDefinition);
            };
        /**
         * @param {?} selector
         * @param {?=} returnElement
         * @return {?}
         */
        MetafrenzyService.prototype.getMetaTag = /**
         * @param {?} selector
         * @param {?=} returnElement
         * @return {?}
         */
            function (selector, returnElement) {
                /** @type {?} */
                var tag = this.meta.getTag(selector);
                if (!tag) {
                    return '';
                }
                return returnElement === true ? tag : tag.content;
            };
        /**
         * @param {?} selector
         * @return {?}
         */
        MetafrenzyService.prototype.removeMetaTag = /**
         * @param {?} selector
         * @return {?}
         */
            function (selector) {
                if (selector instanceof HTMLMetaElement) {
                    this.meta.removeTagElement(selector);
                }
                else {
                    this.meta.removeTag(selector);
                }
            };
        /**
         * @param {?} value
         * @return {?}
         */
        MetafrenzyService.prototype.setMetaCharsetTag = /**
         * @param {?} value
         * @return {?}
         */
            function (value) {
                this.meta.updateTag({
                    charset: value
                }, 'charset');
            };
        /**
         * @param {?} shouldRemoveLinkTagCb
         * @return {?}
         */
        MetafrenzyService.prototype.removeLinkTags = /**
         * @param {?} shouldRemoveLinkTagCb
         * @return {?}
         */
            function (shouldRemoveLinkTagCb) {
                /** @type {?} */
                var links = this.document.head.getElementsByTagName('link');
                /** @type {?} */
                var toRemove = [];
                for (var i = 0; i < links.length; i++) {
                    if (shouldRemoveLinkTagCb(links[i])) {
                        toRemove.push(links[i]);
                    }
                }
                toRemove.forEach(( /**
                 * @param {?} el
                 * @return {?}
                 */function (el) { return el.remove(); }));
            };
        /**
         * @param {?} tag
         * @return {?}
         */
        MetafrenzyService.prototype.setLinkTag = /**
         * @param {?} tag
         * @return {?}
         */
            function (tag) {
                try {
                    /** @type {?} */
                    var renderer_1 = this.rendererFactory.createRenderer(this.document, {
                        id: '-1',
                        encapsulation: core.ViewEncapsulation.None,
                        styles: [],
                        data: {}
                    });
                    /** @type {?} */
                    var link_1 = renderer_1.createElement('link');
                    /** @type {?} */
                    var head = this.document.head;
                    Object.keys(tag).forEach(( /**
                     * @param {?} property
                     * @return {?}
                     */function (property) {
                        return renderer_1.setAttribute(link_1, property, String(tag[property]));
                    }));
                    this.removeLinkTags(( /**
                     * @param {?} el
                     * @return {?}
                     */function (el) {
                        if ((el.getAttribute('name') !== null &&
                            el.getAttribute('name') === link_1.getAttribute('name')) ||
                            (el.getAttribute('rel') !== null &&
                                el.getAttribute('rel') === link_1.getAttribute('rel') &&
                                link_1.getAttribute('rel') !== 'stylesheet' &&
                                link_1.getAttribute('rel') !== 'alternate')) {
                            return true;
                        }
                        return false;
                    }));
                    renderer_1.appendChild(head, link_1);
                }
                catch (e) { }
            };
        /**
         * @param {?} title
         * @return {?}
         */
        MetafrenzyService.prototype.setAllTitleTags = /**
         * @param {?} title
         * @return {?}
         */
            function (title) {
                this.setTitle(title);
                this.setMetaTag('og:title', title);
            };
        /**
         * @param {?} description
         * @return {?}
         */
        MetafrenzyService.prototype.setAllDescriptionTags = /**
         * @param {?} description
         * @return {?}
         */
            function (description) {
                this.setMetaTag('description', description);
                this.setMetaTag('og:description', description);
            };
        /**
         * @param {?} href
         * @return {?}
         */
        MetafrenzyService.prototype.setCanonical = /**
         * @param {?} href
         * @return {?}
         */
            function (href) {
                this.setLinkTag({
                    rel: 'canonical',
                    href: href
                });
            };
        /**
         * @return {?}
         */
        MetafrenzyService.prototype.removeCanonical = /**
         * @return {?}
         */
            function () {
                this.removeLinkTags(( /**
                 * @param {?} el
                 * @return {?}
                 */function (el) { return el.getAttribute('rel') === 'canonical'; }));
            };
        /**
         * @param {?} content
         * @return {?}
         */
        MetafrenzyService.prototype.setRobots = /**
         * @param {?} content
         * @return {?}
         */
            function (content) {
                this.setLinkTag({
                    rel: 'robots',
                    content: content
                });
            };
        /**
         * @param {?} og
         * @return {?}
         */
        MetafrenzyService.prototype.setOpenGraph = /**
         * @param {?} og
         * @return {?}
         */
            function (og) {
                var _this = this;
                Object.keys(og).forEach(( /**
                 * @param {?} name
                 * @return {?}
                 */function (name) {
                    _this.setMetaTag('og:' + name, String(og[name]));
                }));
            };
        /**
         * @param {?} tags
         * @return {?}
         */
        MetafrenzyService.prototype.setTags = /**
         * @param {?} tags
         * @return {?}
         */
            function (tags) {
                if (tags.hasOwnProperty('title') && tags.title) {
                    this.setAllTitleTags(tags.title);
                }
                if (tags.hasOwnProperty('description') && tags.description) {
                    this.setAllDescriptionTags(tags.description);
                }
                if (tags.hasOwnProperty('url') && tags.url) {
                    this.setMetaTag('og:url', tags.url);
                    this.setCanonical(tags.url);
                }
                if (tags.hasOwnProperty('image') && tags.image) {
                    this.setMetaTag('og:image:url', tags.image);
                }
                if (tags.hasOwnProperty('robots') && tags.robots) {
                    this.setRobots(tags.robots);
                }
            };
        MetafrenzyService.decorators = [
            { type: core.Injectable }
        ];
        /** @nocollapse */
        MetafrenzyService.ctorParameters = function () {
            return [
                { type: platformBrowser.Title },
                { type: platformBrowser.Meta },
                { type: core.RendererFactory2 },
                { type: undefined, decorators: [{ type: core.Inject, args: [common.DOCUMENT,] }] }
            ];
        };
        return MetafrenzyService;
    }());

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var MetafrenzyGuard = /** @class */ (function () {
        function MetafrenzyGuard(metafrenzyService) {
            this.metafrenzyService = metafrenzyService;
        }
        /**
         * @param {?} next
         * @param {?} state
         * @return {?}
         */
        MetafrenzyGuard.prototype.canActivate = /**
         * @param {?} next
         * @param {?} state
         * @return {?}
         */
            function (next, state) {
                var _this = this;
                /** @type {?} */
                var metaTags = (next && next.data && next.data.metafrenzy) ? next.data.metafrenzy : null;
                if (metaTags) {
                    for (var key in metaTags) {
                        if (!metaTags.hasOwnProperty(key)) {
                            continue;
                        }
                        /** @type {?} */
                        var value = metaTags[key];
                        if (key === 'title') {
                            this.metafrenzyService.setTitle(value);
                        }
                        else if (key === 'tags') {
                            value.forEach(( /**
                             * @param {?} tag
                             * @return {?}
                             */function (tag) {
                                if ('name' in tag && 'content' in tag) {
                                    _this.metafrenzyService.setMetaTag(tag.name, tag.content);
                                }
                            }));
                        }
                        else if (key === 'links') {
                            value.forEach(( /**
                             * @param {?} link
                             * @return {?}
                             */function (link) {
                                _this.metafrenzyService.setLinkTag(link);
                            }));
                        }
                    }
                }
                return true;
            };
        /**
         * @param {?} next
         * @param {?} state
         * @return {?}
         */
        MetafrenzyGuard.prototype.canActivateChild = /**
         * @param {?} next
         * @param {?} state
         * @return {?}
         */
            function (next, state) {
                return this.canActivate(next, state);
            };
        MetafrenzyGuard.decorators = [
            { type: core.Injectable }
        ];
        /** @nocollapse */
        MetafrenzyGuard.ctorParameters = function () {
            return [
                { type: MetafrenzyService }
            ];
        };
        return MetafrenzyGuard;
    }());

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */
    var MetafrenzyModule = /** @class */ (function () {
        function MetafrenzyModule() {
        }
        /**
         * @return {?}
         */
        MetafrenzyModule.forRoot = /**
         * @return {?}
         */
            function () {
                return {
                    ngModule: MetafrenzyModule,
                    providers: [
                        MetafrenzyService,
                        MetafrenzyGuard
                    ]
                };
            };
        MetafrenzyModule.decorators = [
            { type: core.NgModule, args: [{
                        imports: [
                            common.CommonModule
                        ]
                    },] }
        ];
        return MetafrenzyModule;
    }());

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */

    /**
     * @fileoverview added by tsickle
     * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
     */

    exports.MetafrenzyModule = MetafrenzyModule;
    exports.MetafrenzyGuard = MetafrenzyGuard;
    exports.MetafrenzyService = MetafrenzyService;

    Object.defineProperty(exports, '__esModule', { value: true });

})));

//# sourceMappingURL=ngx-metafrenzy.umd.js.map