import { Meta, Title } from '@angular/platform-browser';
import { DOCUMENT, CommonModule } from '@angular/common';
import { Injectable, RendererFactory2, Inject, ViewEncapsulation, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MetafrenzyService {
    /**
     * @param {?} title
     * @param {?} meta
     * @param {?} rendererFactory
     * @param {?} document
     */
    constructor(title, meta, rendererFactory, document) {
        this.title = title;
        this.meta = meta;
        this.rendererFactory = rendererFactory;
        this.document = document;
    }
    /**
     * @param {?} title
     * @return {?}
     */
    setTitle(title) {
        this.title.setTitle(title);
    }
    /**
     * @return {?}
     */
    getTitle() {
        return this.title.getTitle();
    }
    /**
     * @param {?} name
     * @param {?} content
     * @return {?}
     */
    setMetaTag(name, content) {
        /** @type {?} */
        const metaDefinition = {};
        if (name.lastIndexOf('og:', 0) === 0) {
            metaDefinition['property'] = name;
        }
        else {
            metaDefinition['name'] = name;
        }
        metaDefinition['content'] = content;
        this.meta.updateTag(metaDefinition);
    }
    /**
     * @param {?} selector
     * @param {?=} returnElement
     * @return {?}
     */
    getMetaTag(selector, returnElement) {
        /** @type {?} */
        const tag = this.meta.getTag(selector);
        if (!tag) {
            return '';
        }
        return returnElement === true ? tag : tag.content;
    }
    /**
     * @param {?} selector
     * @return {?}
     */
    removeMetaTag(selector) {
        if (selector instanceof HTMLMetaElement) {
            this.meta.removeTagElement(selector);
        }
        else {
            this.meta.removeTag(selector);
        }
    }
    /**
     * @param {?} value
     * @return {?}
     */
    setMetaCharsetTag(value) {
        this.meta.updateTag({
            charset: value
        }, 'charset');
    }
    /**
     * @param {?} shouldRemoveLinkTagCb
     * @return {?}
     */
    removeLinkTags(shouldRemoveLinkTagCb) {
        /** @type {?} */
        const links = this.document.head.getElementsByTagName('link');
        /** @type {?} */
        const toRemove = [];
        for (let i = 0; i < links.length; i++) {
            if (shouldRemoveLinkTagCb(links[i])) {
                toRemove.push(links[i]);
            }
        }
        toRemove.forEach((/**
         * @param {?} el
         * @return {?}
         */
        el => el.remove()));
    }
    /**
     * @param {?} tag
     * @return {?}
     */
    setLinkTag(tag) {
        try {
            /** @type {?} */
            const renderer = this.rendererFactory.createRenderer(this.document, {
                id: '-1',
                encapsulation: ViewEncapsulation.None,
                styles: [],
                data: {}
            });
            /** @type {?} */
            const link = renderer.createElement('link');
            /** @type {?} */
            const head = this.document.head;
            Object.keys(tag).forEach((/**
             * @param {?} property
             * @return {?}
             */
            (property) => {
                return renderer.setAttribute(link, property, String(tag[property]));
            }));
            this.removeLinkTags((/**
             * @param {?} el
             * @return {?}
             */
            el => {
                if ((el.getAttribute('name') !== null &&
                    el.getAttribute('name') === link.getAttribute('name')) ||
                    (el.getAttribute('rel') !== null &&
                        el.getAttribute('rel') === link.getAttribute('rel') &&
                        link.getAttribute('rel') !== 'stylesheet' &&
                        link.getAttribute('rel') !== 'alternate')) {
                    return true;
                }
                return false;
            }));
            renderer.appendChild(head, link);
        }
        catch (e) { }
    }
    /**
     * @param {?} title
     * @return {?}
     */
    setAllTitleTags(title) {
        this.setTitle(title);
        this.setMetaTag('og:title', title);
    }
    /**
     * @param {?} description
     * @return {?}
     */
    setAllDescriptionTags(description) {
        this.setMetaTag('description', description);
        this.setMetaTag('og:description', description);
    }
    /**
     * @param {?} href
     * @return {?}
     */
    setCanonical(href) {
        this.setLinkTag({
            rel: 'canonical',
            href
        });
    }
    /**
     * @return {?}
     */
    removeCanonical() {
        this.removeLinkTags((/**
         * @param {?} el
         * @return {?}
         */
        el => el.getAttribute('rel') === 'canonical'));
    }
    /**
     * @param {?} content
     * @return {?}
     */
    setRobots(content) {
        this.setLinkTag({
            rel: 'robots',
            content
        });
    }
    /**
     * @param {?} og
     * @return {?}
     */
    setOpenGraph(og) {
        Object.keys(og).forEach((/**
         * @param {?} name
         * @return {?}
         */
        (name) => {
            this.setMetaTag('og:' + name, String(og[name]));
        }));
    }
    /**
     * @param {?} tags
     * @return {?}
     */
    setTags(tags) {
        if (tags.hasOwnProperty('title') && tags.title) {
            this.setAllTitleTags(tags.title);
        }
        if (tags.hasOwnProperty('description') && tags.description) {
            this.setAllDescriptionTags(tags.description);
        }
        if (tags.hasOwnProperty('url') && tags.url) {
            this.setMetaTag('og:url', tags.url);
            this.setCanonical(tags.url);
        }
        if (tags.hasOwnProperty('image') && tags.image) {
            this.setMetaTag('og:image:url', tags.image);
        }
        if (tags.hasOwnProperty('robots') && tags.robots) {
            this.setRobots(tags.robots);
        }
    }
}
MetafrenzyService.decorators = [
    { type: Injectable }
];
/** @nocollapse */
MetafrenzyService.ctorParameters = () => [
    { type: Title },
    { type: Meta },
    { type: RendererFactory2 },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MetafrenzyGuard {
    /**
     * @param {?} metafrenzyService
     */
    constructor(metafrenzyService) {
        this.metafrenzyService = metafrenzyService;
    }
    /**
     * @param {?} next
     * @param {?} state
     * @return {?}
     */
    canActivate(next, state) {
        /** @type {?} */
        const metaTags = (next && next.data && next.data.metafrenzy) ? next.data.metafrenzy : null;
        if (metaTags) {
            for (const key in metaTags) {
                if (!metaTags.hasOwnProperty(key)) {
                    continue;
                }
                /** @type {?} */
                const value = metaTags[key];
                if (key === 'title') {
                    this.metafrenzyService.setTitle(value);
                }
                else if (key === 'tags') {
                    value.forEach((/**
                     * @param {?} tag
                     * @return {?}
                     */
                    (tag) => {
                        if ('name' in tag && 'content' in tag) {
                            this.metafrenzyService.setMetaTag(tag.name, tag.content);
                        }
                    }));
                }
                else if (key === 'links') {
                    value.forEach((/**
                     * @param {?} link
                     * @return {?}
                     */
                    (link) => {
                        this.metafrenzyService.setLinkTag(link);
                    }));
                }
            }
        }
        return true;
    }
    /**
     * @param {?} next
     * @param {?} state
     * @return {?}
     */
    canActivateChild(next, state) {
        return this.canActivate(next, state);
    }
}
MetafrenzyGuard.decorators = [
    { type: Injectable }
];
/** @nocollapse */
MetafrenzyGuard.ctorParameters = () => [
    { type: MetafrenzyService }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class MetafrenzyModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: MetafrenzyModule,
            providers: [
                MetafrenzyService,
                MetafrenzyGuard
            ]
        };
    }
}
MetafrenzyModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { MetafrenzyModule, MetafrenzyGuard, MetafrenzyService };

//# sourceMappingURL=ngx-metafrenzy.js.map